@@ -37,33 +37,26 @@ QStringList BlockDeviceInfo::split(const QString &devname)
 // return block device info that is suitable for a combo box
 void BlockDeviceInfo::addToCombo(QComboBox *combo, bool warnNasty) const
 {
-    const char *suffixes[] = {"B", "KB", "MB", "GB", "TB", "PB", "EB"};
-    unsigned int isuffix = 0;
-    long long scalesize = size;
-    while (scalesize >= 1024 && isuffix < sizeof(suffixes)) {
-        ++isuffix;
-        scalesize /= 1024;
-    }
-    QString strout(name + " (" + QString::number(scalesize) + suffixes[isuffix]);
+    QString strout(QLocale::system().formattedDataSize(size, 1, QLocale::DataSizeTraditionalFormat));
     if (!fs.isEmpty()) strout += " " + fs;
     if (!label.isEmpty()) strout += " - " + label;
     if (!model.isEmpty()) strout += (label.isEmpty() ? " - " : "; ") + model;
     QString stricon;
     if (isFuture) stricon = "appointment-soon-symbolic";
     else if (isNasty && warnNasty) stricon = "dialog-warning-symbolic";
-    combo->addItem(QIcon::fromTheme(stricon), strout + ")", name);
+    combo->addItem(QIcon::fromTheme(stricon), name + " (" + strout + ")", name);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
 void BlockDeviceList::build(MProcess &proc)
 {
-    proc.exec("/sbin/partprobe", true);
+    proc.exec("partprobe -s", true);
     proc.exec("blkid -c /dev/null", true);
 
     // expressions for matching various partition types
     const QRegularExpression rxESP("^(c12a7328-f81f-11d2-ba4b-00a0c93ec93b|0xef)$");
-    const QRegularExpression rxSwap("^(0x82|0657fd6d-a4ab-43c4-84e5-0933c84b4f4f)$");
+    const QRegularExpression rxSwap("^(swap)$");
     const QRegularExpression rxNative("^(0x83|0fc63daf-8483-4772-8e79-3d69d8477de4" // Linux data
                                       "|0x82|0657fd6d-a4ab-43c4-84e5-0933c84b4f4f" // Linux swap
                                       "|44479540-f297-41b2-9af7-d131d5f0458a" // Linux /root x86
@@ -82,12 +75,28 @@ void BlockDeviceList::build(MProcess &proc)
     // backup detection for drives that don't have UUID for ESP
     const QStringList backup_list = proc.execOutLines("fdisk -l -o DEVICE,TYPE |grep 'EFI System' |cut -d\\  -f1 | cut -d/ -f3");
 
+    // collect and sort lsblk info (sorting required for drives with >15 partitions)
+    const QStringList &bdraw = proc.execOutLines("lsblk -brno TYPE,NAME,UUID,SIZE,PARTTYPE,FSTYPE,LABEL,MODEL");
+    QStringList blkdevs, bdrives, bparts;
+    for (const QString &blkdev : bdraw) {
+        const QString &bdtype = blkdev.section(' ', 0, 0);
+        if (bdtype == "disk") bdrives << blkdev;
+        else if (bdtype == "part") bparts << blkdev;
+    }
+    for (const QString &bdrive : bdrives) {
+        blkdevs << bdrive;
+        for (QString &bpart : bparts) {
+            if (bpart.section(' ', 1, 1).startsWith(bdrive.section(' ', 1, 1))) {
+                blkdevs.append(bpart);
+                bpart.clear();
+            }
+        }
+    }
+
     // populate the block device list
     clear();
     bool gpt = false; // propagates to all partitions within the drive
     int driveIndex = 0; // for propagating the nasty flag to the drive
-    const QStringList &blkdevs = proc.execOutLines("lsblk -brno TYPE,NAME,UUID,SIZE,PARTTYPE,FSTYPE,LABEL,MODEL |sed 's/├─//' |sed 's/└─//' "
-                                            " | grep -E '^(disk|part)'");
     for (const QString &blkdev : blkdevs) {
         const QStringList &bdsegs = blkdev.split(' ');
         const int segsize = bdsegs.size();
@@ -110,7 +119,7 @@ void BlockDeviceList::build(MProcess &proc)
         if (segsize > 4) {
             const QString &seg4 = bdsegs.at(4);
             bdinfo.isESP = (seg4.count(rxESP) >= 1);
-            bdinfo.isSwap = (seg4.count(rxSwap) >= 1);
+           // bdinfo.isSwap = (seg4.count(rxSwap) >= 1);
             bdinfo.isNative = (seg4.count(rxNative) >= 1);
             if (!bdinfo.isNasty) bdinfo.isNasty = (seg4.count(rxWinLDM) >= 1);
         } else {
@@ -122,6 +131,8 @@ void BlockDeviceList::build(MProcess &proc)
             bdinfo.isESP = backup_list.contains(bdinfo.name);
         }
         if (segsize > 5) {
+            const QString &seg5 = bdsegs.at(5);
+            bdinfo.isSwap = (seg5.count(rxSwap) >= 1);
             bdinfo.fs = bdsegs.at(5);
             if(bdinfo.fs.count(rxNativeFS) >= 1) bdinfo.isNative = true;
         }
